@@ -1,6 +1,6 @@
 from typing import TYPE_CHECKING
 
-from flake8_typing_only_imports.ast import Scanner
+from flake8_typing_only_imports.ast import Checker
 
 if TYPE_CHECKING:
     from ast import Module
@@ -18,5 +18,5 @@ class Plugin:
 
     def run(self) -> 'Generator':
         """Run flake8 plugin and return any relevant errors."""
-        visitor = Scanner(self.tree)
+        visitor = Checker(self.tree)
         yield from visitor.errors
